@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/phpldapadmin/phpldapadmin/htdocs/refresh.php,v 1.18.2.1 2007/12/26 09:26:32 wurley Exp $
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/htdocs/refresh.php,v 1.18.2.2 2008/12/12 12:20:22 wurley Exp $
 
 /**
  * This script alters the session variable 'tree', by re-querying
@@ -14,7 +14,7 @@
 require './common.php';
 
 if (! $_SESSION[APPCONFIG]->isCommandAvailable('server_refresh'))
-	pla_error(sprintf('%s%s %s',_('This operation is not permitted by the configuration'),_(':'),_('refresh server')));
+	error(sprintf('%s%s %s',_('This operation is not permitted by the configuration'),_(':'),_('refresh server')),'error','index.php');
 
 unset($_SESSION['cache'][$ldapserver->server_id]['tree']);
 
